# AUTOGENERATED! DO NOT EDIT! File to edit: ../../pts/api/test123/folder/subfolder/notebook7.pct.py.

# %% auto 0
__all__ = ['foobar']

# %% ../../pts/api/test123/folder/subfolder/notebook7.pct.py 3
def foobar():
    pass
