# AUTOGENERATED! DO NOT EDIT! File to edit: ../../pts/api/test123/notebook2.pct.py.

# %% auto 0
__all__ = ['bar']

# %% ../../pts/api/test123/notebook2.pct.py 3
from my_module.notebook1 import foo

# %% ../../pts/api/test123/notebook2.pct.py 4
def bar():
    foo()
    print("world")
