# AUTOGENERATED! DO NOT EDIT! File to edit: ../../../../../../../../Users/lukastk/dev-proj/nblite/pts/api/test123/func_notebook.pct.py.

# %% top_export
def a_decorator(func):
    def wrapper(*args, **kwargs):
        print("Function is being called")
        result = func(*args, **kwargs)
        print("Function has been called")
        return result
    return wrapper

@a_decorator
def nb_func(): 
    # %% ../../../../../../../../Users/lukastk/dev-proj/nblite/pts/api/test123/func_notebook.pct.py 4
    print("This will be in the body of the function.")
    my_val = "Hello, world!"
    return my_val