# AUTOGENERATED! DO NOT EDIT! File to edit: ../../pts/api/test123/folder/notebook4.pct.py.

# %% auto 0
__all__ = ['foobar']

# %% ../../pts/api/test123/folder/notebook4.pct.py 3
from my_module.notebook1 import foo
from my_module.notebook2 import bar

# %% ../../pts/api/test123/folder/notebook4.pct.py 4
def foobar():
    foo()
    bar()
